@@ -3,7 +3,7 @@
 from lazpaint import dialog
 
 try:
-    from tkinter import *
+    from tkinter import Tk, Frame, Label, Scale, HORIZONTAL, Button, RIGHT, W, E
 except ImportError:
     dialog.show_message("Please install tkinter. On Debian distributions, use the command: apt install python3-tk")
     exit()
@@ -11,7 +11,8 @@ except ImportError:
 from lazpaint import colors, image, layer, filters, tools, selection
 import math
 
-translation = dialog.translate_dict(["Layer is empty", "Radius", "Angle", "Opacity", "Ok", "Cancel"])
+translation = dialog.translate_dict(["Layer is empty", "Radius", "Angle", 
+    "Opacity", "Ok", "Cancel", "Run this script again to update effect"])
 
 if layer.is_empty():
     dialog.show_message(translation["Layer is empty"])
@@ -239,6 +240,11 @@ scale_opacity = Scale(frame, from_=0, to=MAX_OPACITY, orient=HORIZONTAL, command
 scale_opacity.grid(column=1, row=2, sticky=W+E, padx=10)
 scale_opacity.set(chosen_opacity)
 
+label_info = Label(frame, text=translation["Run this script again to update effect"],
+    background="lemon chiffon", foreground="black", borderwidth=1, relief="solid")
+label_info.grid(column=0, rows=3, columnspan=2)
+
+
 frame.columnconfigure(0, pad=20)
 frame.columnconfigure(1, minsize=250)
 frame.rowconfigure(0, pad=20)
